#!/bin/bash
#
# Copyright 2013 Univention GmbH
#
# http://www.univention.de/
#
# All rights reserved.
#
# The source code of this program is made available
# under the terms of the GNU Affero General Public License version 3
# (GNU AGPL V3) as published by the Free Software Foundation.
#
# Binary versions of this program provided by Univention to you as
# well as other copyrighted, protected or trademarked materials like
# Logos, graphics, fonts, specific documentations and configurations,
# cryptographic keys etc. are subject to a license agreement between
# you and Univention and not subject to the GNU AGPL V3.
#
# In the case you use this program under the terms of the GNU AGPL V3,
# the program is provided in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public
# License with the Debian GNU/Linux or Univention distribution in file
# /usr/share/common-licenses/AGPL-3; if not, see
# <http://www.gnu.org/licenses/>.

. /usr/share/univention-lib/ucr.sh

customer=LMZ
customer_lowercase="$(echo "${customer}"|tr '[:upper:]' '[:lower:]')"

if [ "${1}" = "--help" -o "${1}" = "-h" ]; then
	echo
	echo "Activates/deactivates the ${customer} branding for the Univention Management Console."
	echo
	echo "usage: $(basename "${0}") [true|false]"
	echo
	echo "Without any options, the script activates the ${customer} branding in case the UCR varialbe"
	echo "'univention-lmz-directory-integration/paedml' is set to true."
	echo "If 'true' or 'false' is given as parameter, the value of the UCR variable will be"
	echo "ignored and overriden by the given parameter."
	echo
	exit 0
fi

exec >> /var/log/univention/branding-switch.log 2>&1

# variables
styleFile=/usr/share/univention-management-console-frontend/js/dijit/themes/umc/umc.css
oldStyleFile="${styleFile}.debian"
# search command from the directory of this file
# find ../univention-management-console-frontend/ -type f | egrep -v  '\.(orig|bak|disabled)$' | sed -e 's/^\.\./\/usr\/share/;s/\.lmz//'
# find ../favicon.ico ../ucs-overview -type f | egrep -v  '\.(orig|bak|disabled)$' | sed -ne 's/^\.\./\/var\/www/;s/\.lmz//p'

divertFiles=( \
	/usr/share/univention-management-console-frontend/js/dijit/themes/umc/bg_images/page.png \
	/usr/share/univention-management-console-frontend/js/dijit/themes/umc/bg_images/top.png \
	/usr/share/univention-management-console-frontend/js/dijit/themes/umc/favicon.ico \
	/usr/share/univention-management-console-frontend/js/dijit/themes/umc/form/images/button.png \
	/usr/share/univention-management-console-frontend/js/dijit/themes/umc/icons/16x16/univention.png \
	/usr/share/univention-management-console-frontend/js/dijit/themes/umc/umc.css \
	/usr/share/univention-management-console-frontend/js/dijit/themes/umc/univention_logo.png \
	/usr/share/univention-management-console-frontend/js/umc/app/about.de.html \
	/usr/share/univention-management-console-frontend/js/umc/app/about.en.html \
	/usr/share/univention-management-console-frontend/js/umc/app/help.de.html \
	/usr/share/univention-management-console-frontend/js/umc/app/help.en.html \
	/usr/share/univention-management-console-frontend/js/umc/i18n/de/branding.json \
	/usr/share/univention-management-console-frontend/js/umc/i18n/en/branding.json \
	/var/www/ucs-overview/css/style.css \
	/var/www/ucs-overview/js/startsite.js \
	/var/www/ucs-overview/js/de.json \
	/var/www/ucs-overview/index.html \
	/var/www/ucs-overview/img/elements/powered-by-Univention.png \
	/var/www/ucs-overview/img/elements/logo.png \
	/var/www/ucs-overview/img/elements/logo_mobile.png \
	/var/www/ucs-overview/img/elements/red_arrow.png \
	/var/www/ucs-overview/img/backgrounds/header_bg.png \
	/var/www/ucs-overview/img/backgrounds/header_bg_mobile.png \
	/var/www/favicon.ico \
	/etc/univention/templates/files/etc/issue \
	/etc/univention/templates/files/etc/issue.net \
	/etc/univention/templates/files/etc/welcome.msg \
	)

# check current branding (CUSTOMER|default)
currentBranding=default
if [ -n "$(dpkg-divert --list "${styleFile}")" ]; then
	currentBranding="${customer_lowercase}"
fi

# check the given parameters
newBranding=default
force=
if [ "${1}" = "true" ]; then
	newBranding="${customer_lowercase}"
	force=1
elif [ "${1}" = "false" ]; then
	newBranding=default
	force=1
elif is_ucr_true univention-lmz-directory-integration/paedml; then
	newBranding="${customer_lowercase}"
fi

# do we need to change the branding?
echo "=== $(date) ==="
echo "cmdline: ${0} ${@}"
ucr search univention-lmz-directory-integration/paedml
echo "currentBranding=${currentBranding}    newBranding=${newBranding}"

if [ "${newBranding}" != "${currentBranding}" ] || [ -n "${force}" ]; then
	if [ "${newBranding}" = "${customer_lowercase}" ]; then
		# branding, install a diversion for the UMC files and create a symlink to the files
		for iFile in "${divertFiles[@]}"; do
			dpkg-divert --package lmz-branding --divert "${iFile}.debian" --rename "${iFile}"
			ln -s "${iFile}.${customer_lowercase}" "${iFile}"
			# prevent caching problems
			touch "${iFile}"
		done
	else
		# default branding, remove the link to files and remove the diversions
		for iFile in "${divertFiles[@]}"; do
			test -L "${iFile}" && rm "${iFile}"
			dpkg-divert --package lmz-branding --rename --remove "${iFile}"
			# prevent caching problems
			touch "${iFile}"
		done
	fi
	. /usr/share/univention-lib/umc.sh
	umc_frontend_new_hash
fi

echo "done."
